@@ -1,6 +1,6 @@
-linux-6.18.7-sparky for Debian
+linux-6.18.9-sparky for Debian
 -----------------------------
 
 <Possible notes regarding this package - if none, delete this file.>
 
- -- pavroo <pavroo@onet.eu>  Fri, 23 Jan 2026 15:32:49 +0100
+ -- pavroo <pavroo@onet.eu>  Sat, 07 Feb 2026 12:01:33 +0100
