@@ -1,4 +1,4 @@
-linux-6.18.7-sparky for Debian
+linux-6.18.9-sparky for Debian
 -----------------------------
 
 <This file describes information about the source package, see Debian policy
@@ -6,4 +6,4 @@ manual section 4.14. You WILL either need to modify or delete this file.>
 
 
 
- -- pavroo <pavroo@onet.eu>  Fri, 23 Jan 2026 15:32:49 +0100
+ -- pavroo <pavroo@onet.eu>  Sat, 07 Feb 2026 12:01:33 +0100
