@@ -4,7 +4,7 @@
 .\" First parameter, NAME, should be all caps
 .\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
 .\" other parameters are allowed: see man(7), man(1)
-.TH Linux-6.18.7-sparky SECTION "January 23 2026"
+.TH Linux-6.18.9-sparky SECTION "February  7 2026"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 .\" Some roff macros, for reference:
@@ -18,16 +18,16 @@
 .\" .sp <n>    insert n+1 empty lines
 .\" for manpage-specific macros, see man(7)
 .SH NAME
-linux-6.18.7-sparky \- program to do something
+linux-6.18.9-sparky \- program to do something
 .SH SYNOPSIS
-.B linux-6.18.7-sparky
+.B linux-6.18.9-sparky
 .RI [ options ] " files" ...
 .br
 .B bar
 .RI [ options ] " files" ...
 .SH DESCRIPTION
 This manual page documents briefly the
-.B linux-6.18.7-sparky
+.B linux-6.18.9-sparky
 and
 .B bar
 commands.
@@ -35,7 +35,7 @@ commands.
 .\" TeX users may be more comfortable with the \fB<whatever>\fP and
 .\" \fI<whatever>\fP escape sequences to invode bold face and italics,
 .\" respectively.
-\fBlinux-6.18.7-sparky\fP is a program that...
+\fBlinux-6.18.9-sparky\fP is a program that...
 .SH OPTIONS
 These programs follow the usual GNU command line syntax, with long
 options starting with two dashes ('\-').
