@@ -1,6 +1,6 @@
-% linux-6.18.7-sparky(SECTION) | User Commands
+% linux-6.18.9-sparky(SECTION) | User Commands
 %
-% "January 23 2026"
+% "February  7 2026"
 
 [comment]: # The lines above form a Pandoc metadata block. They must be
 [comment]: # the first ones in the file.
@@ -33,24 +33,24 @@
 
 # NAME
 
-linux-6.18.7-sparky - program to do something
+linux-6.18.9-sparky - program to do something
 
 # SYNOPSIS
 
-**linux-6.18.7-sparky** **-e** _this_ [**\-\-example=that**] [{**-e** | **\-\-example**} _this_]
+**linux-6.18.9-sparky** **-e** _this_ [**\-\-example=that**] [{**-e** | **\-\-example**} _this_]
                  [{**-e** | **\-\-example**} {_this_ | _that_}]
 
-**linux-6.18.7-sparky** [{**-h** | *\-\-help**} | {**-v** | **\-\-version**}]
+**linux-6.18.9-sparky** [{**-h** | *\-\-help**} | {**-v** | **\-\-version**}]
 
 # DESCRIPTION
 
-This manual page documents briefly the **linux-6.18.7-sparky** and **bar** commands.
+This manual page documents briefly the **linux-6.18.9-sparky** and **bar** commands.
 
 This manual page was written for the Debian distribution because the
 original program does not have a manual page. Instead, it has documentation
 in the GNU info(1) format; see below.
 
-**linux-6.18.7-sparky** is a program that...
+**linux-6.18.9-sparky** is a program that...
 
 # OPTIONS
 
@@ -71,11 +71,11 @@ a complete description, see the **info**(1) files.
 
 /etc/foo.conf
 :   The system-wide configuration file to control the behaviour of
-    linux-6.18.7-sparky. See **foo.conf**(5) for further details.
+    linux-6.18.9-sparky. See **foo.conf**(5) for further details.
 
 ${HOME}/.foo.conf
 :   The per-user configuration file to control the behaviour of
-    linux-6.18.7-sparky. See **foo.conf**(5) for further details.
+    linux-6.18.9-sparky. See **foo.conf**(5) for further details.
 
 # ENVIRONMENT
 
@@ -91,7 +91,7 @@ Bad configuration file. Exiting.
 :   The configuration file seems to contain a broken configuration
     line. Use the **\-\-verbose** option, to get more info.
 
-**linux-6.18.7-sparky** provides some return codes, that can be used in scripts:
+**linux-6.18.9-sparky** provides some return codes, that can be used in scripts:
 
     Code Diagnostic
     0 Program exited successfully.
