@@ -20,14 +20,14 @@ manpage.1: manpage.sgml
   <!ENTITY dhfirstname "<firstname>FIRSTNAME</firstname>">
   <!ENTITY dhsurname   "<surname>SURNAME</surname>">
   <!-- Please adjust the date whenever revising the manpage. -->
-  <!ENTITY dhdate      "<date>January 23 2026</date>">
+  <!ENTITY dhdate      "<date>February  7 2026</date>">
   <!-- SECTION should be 1-8, maybe w/ subsection other parameters are
        allowed: see man(7), man(1). -->
   <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
   <!ENTITY dhemail     "<email>pavroo@onet.eu</email>">
   <!ENTITY dhusername  "pavroo">
-  <!ENTITY dhucpackage "<refentrytitle>Linux-6.18.7-sparky</refentrytitle>">
-  <!ENTITY dhpackage   "linux-6.18.7-sparky">
+  <!ENTITY dhucpackage "<refentrytitle>Linux-6.18.9-sparky</refentrytitle>">
+  <!ENTITY dhpackage   "linux-6.18.9-sparky">
 
   <!ENTITY debian      "<productname>Debian</productname>">
   <!ENTITY gnu         "<acronym>GNU</acronym>">
